#
# SPDX-FileCopyrightText: Copyright (c) provide.io llc. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
#

"""Terraform-specific HCL processing module."""

from pyvider.hcl.terraform.config import parse_terraform_config

__all__ = [
    "parse_terraform_config",
]

# 📄⚙️🔚
