#
# SPDX-FileCopyrightText: Copyright (c) provide.io llc. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
#

"""CTY value output and formatting module."""

from pyvider.hcl.output.formatting import pretty_print_cty

__all__ = [
    "pretty_print_cty",
]

# 📄⚙️🔚
